Struct ProxyEvent
pub struct ProxyEvent { /* private fields */ }Expand description
A sendable event payload used by context proxies to forward events from non-UI threads.
Implementations
impl ProxyEvent
impl ProxyEvent
pub fn new<M>(message: M) -> ProxyEvent
pub fn new<M>(message: M) -> ProxyEvent
Creates a new proxy event with a sendable message.
pub fn target(self, entity: Entity) -> ProxyEvent
pub fn target(self, entity: Entity) -> ProxyEvent
Sets the target of the event.
pub fn origin(self, entity: Entity) -> ProxyEvent
pub fn origin(self, entity: Entity) -> ProxyEvent
Sets the origin of the event.
pub fn propagate(self, propagation: Propagation) -> ProxyEvent
pub fn propagate(self, propagation: Propagation) -> ProxyEvent
Sets the propagation of the event.
pub fn into_event(self) -> Event
pub fn into_event(self) -> Event
Converts a proxy event into a normal event on the UI thread.